@@ -90,7 +90,9 @@ class Dependable(metaclass=jsii.JSIIAbstractClass, jsii_type="constructs.Dependa
         :stability: deprecated
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Dependable.get)
+            def stub(instance: IDependable) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument instance", value=instance, expected_type=type_hints["instance"])
         return typing.cast("Dependable", jsii.sinvoke(cls, "get", [instance]))
 
@@ -105,7 +107,9 @@ class Dependable(metaclass=jsii.JSIIAbstractClass, jsii_type="constructs.Dependa
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Dependable.implement)
+            def stub(instance: IDependable, trait: Dependable) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument instance", value=instance, expected_type=type_hints["instance"])
             check_type(argname="argument trait", value=trait, expected_type=type_hints["trait"])
         return typing.cast(None, jsii.sinvoke(cls, "implement", [instance, trait]))
@@ -120,7 +124,9 @@ class Dependable(metaclass=jsii.JSIIAbstractClass, jsii_type="constructs.Dependa
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Dependable.of)
+            def stub(instance: IDependable) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument instance", value=instance, expected_type=type_hints["instance"])
         return typing.cast("Dependable", jsii.sinvoke(cls, "of", [instance]))
 
@@ -246,7 +252,14 @@ class MetadataEntry:
         :param trace: Stack trace at the point of adding the metadata. Only available if ``addMetadata()`` is called with ``stackTrace: true``. Default: - no trace information
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(MetadataEntry.__init__)
+            def stub(
+                *,
+                data: typing.Any,
+                type: builtins.str,
+                trace: typing.Optional[typing.Sequence[builtins.str]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument data", value=data, expected_type=type_hints["data"])
             check_type(argname="argument type", value=type, expected_type=type_hints["type"])
             check_type(argname="argument trace", value=trace, expected_type=type_hints["trace"])
@@ -315,7 +328,13 @@ class MetadataOptions:
         :param trace_from_function: A JavaScript function to begin tracing from. This option is ignored unless ``stackTrace`` is ``true``. Default: addMetadata()
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(MetadataOptions.__init__)
+            def stub(
+                *,
+                stack_trace: typing.Optional[builtins.bool] = None,
+                trace_from_function: typing.Any = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument stack_trace", value=stack_trace, expected_type=type_hints["stack_trace"])
             check_type(argname="argument trace_from_function", value=trace_from_function, expected_type=type_hints["trace_from_function"])
         self._values: typing.Dict[str, typing.Any] = {}
@@ -371,7 +390,9 @@ class Node(metaclass=jsii.JSIIMeta, jsii_type="constructs.Node"):
         :param id: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Node.__init__)
+            def stub(host: Construct, scope: IConstruct, id: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument host", value=host, expected_type=type_hints["host"])
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
@@ -389,7 +410,9 @@ class Node(metaclass=jsii.JSIIMeta, jsii_type="constructs.Node"):
         :stability: deprecated
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Node.of)
+            def stub(construct: IConstruct) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument construct", value=construct, expected_type=type_hints["construct"])
         return typing.cast("Node", jsii.sinvoke(cls, "of", [construct]))
 
@@ -402,7 +425,9 @@ class Node(metaclass=jsii.JSIIMeta, jsii_type="constructs.Node"):
         :param deps: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Node.add_dependency)
+            def stub(*deps: IDependable) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument deps", value=deps, expected_type=typing.Tuple[type_hints["deps"], ...]) # pyright: ignore [reportGeneralTypeIssues]
         return typing.cast(None, jsii.invoke(self, "addDependency", [*deps]))
 
@@ -427,7 +452,15 @@ class Node(metaclass=jsii.JSIIMeta, jsii_type="constructs.Node"):
         :param trace_from_function: A JavaScript function to begin tracing from. This option is ignored unless ``stackTrace`` is ``true``. Default: addMetadata()
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Node.add_metadata)
+            def stub(
+                type: builtins.str,
+                data: typing.Any,
+                *,
+                stack_trace: typing.Optional[builtins.bool] = None,
+                trace_from_function: typing.Any = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument type", value=type, expected_type=type_hints["type"])
             check_type(argname="argument data", value=data, expected_type=type_hints["data"])
         options = MetadataOptions(
@@ -446,7 +479,9 @@ class Node(metaclass=jsii.JSIIMeta, jsii_type="constructs.Node"):
         :param validation: The validation object.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Node.add_validation)
+            def stub(validation: IValidation) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument validation", value=validation, expected_type=type_hints["validation"])
         return typing.cast(None, jsii.invoke(self, "addValidation", [validation]))
 
@@ -460,7 +495,9 @@ class Node(metaclass=jsii.JSIIMeta, jsii_type="constructs.Node"):
         :param order: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Node.find_all)
+            def stub(order: typing.Optional[ConstructOrder] = None) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument order", value=order, expected_type=type_hints["order"])
         return typing.cast(typing.List["IConstruct"], jsii.invoke(self, "findAll", [order]))
 
@@ -475,7 +512,9 @@ class Node(metaclass=jsii.JSIIMeta, jsii_type="constructs.Node"):
         :return: Child with the given id.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Node.find_child)
+            def stub(id: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         return typing.cast("IConstruct", jsii.invoke(self, "findChild", [id]))
 
@@ -499,7 +538,9 @@ class Node(metaclass=jsii.JSIIMeta, jsii_type="constructs.Node"):
         :param value: The context value.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Node.set_context)
+            def stub(key: builtins.str, value: typing.Any) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument key", value=key, expected_type=type_hints["key"])
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         return typing.cast(None, jsii.invoke(self, "setContext", [key, value]))
@@ -513,7 +554,9 @@ class Node(metaclass=jsii.JSIIMeta, jsii_type="constructs.Node"):
         :return: the child if found, or undefined
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Node.try_find_child)
+            def stub(id: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         return typing.cast(typing.Optional["IConstruct"], jsii.invoke(self, "tryFindChild", [id]))
 
@@ -528,7 +571,9 @@ class Node(metaclass=jsii.JSIIMeta, jsii_type="constructs.Node"):
         :return: The context value or ``undefined`` if there is no context value for thie key.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Node.try_get_context)
+            def stub(key: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument key", value=key, expected_type=type_hints["key"])
         return typing.cast(typing.Any, jsii.invoke(self, "tryGetContext", [key]))
 
@@ -543,7 +588,9 @@ class Node(metaclass=jsii.JSIIMeta, jsii_type="constructs.Node"):
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Node.try_remove_child)
+            def stub(child_name: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument child_name", value=child_name, expected_type=type_hints["child_name"])
         return typing.cast(builtins.bool, jsii.invoke(self, "tryRemoveChild", [child_name]))
 
@@ -689,7 +736,9 @@ class Node(metaclass=jsii.JSIIMeta, jsii_type="constructs.Node"):
     @default_child.setter
     def default_child(self, value: typing.Optional["IConstruct"]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Node, "default_child").fset)
+            def stub(value: typing.Optional[IConstruct]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "defaultChild", value)
 
@@ -711,7 +760,9 @@ class DependencyGroup(metaclass=jsii.JSIIMeta, jsii_type="constructs.DependencyG
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(DependencyGroup.__init__)
+            def stub(*deps: IDependable) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument deps", value=deps, expected_type=typing.Tuple[type_hints["deps"], ...]) # pyright: ignore [reportGeneralTypeIssues]
         jsii.create(self.__class__, self, [*deps])
 
@@ -724,7 +775,9 @@ class DependencyGroup(metaclass=jsii.JSIIMeta, jsii_type="constructs.DependencyG
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(DependencyGroup.add)
+            def stub(*scopes: IDependable) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scopes", value=scopes, expected_type=typing.Tuple[type_hints["scopes"], ...]) # pyright: ignore [reportGeneralTypeIssues]
         return typing.cast(None, jsii.invoke(self, "add", [*scopes]))
 
@@ -772,7 +825,9 @@ class Construct(metaclass=jsii.JSIIMeta, jsii_type="constructs.Construct"):
         :param id: The scoped construct ID. Must be unique amongst siblings. If the ID includes a path separator (``/``), then it will be replaced by double dash ``--``.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Construct.__init__)
+            def stub(scope: Construct, id: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         jsii.create(self.__class__, self, [scope, id])
@@ -801,7 +856,9 @@ class Construct(metaclass=jsii.JSIIMeta, jsii_type="constructs.Construct"):
         :return: true if ``x`` is an object created from a class which extends ``Construct``.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Construct.is_construct)
+            def stub(x: typing.Any) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument x", value=x, expected_type=type_hints["x"])
         return typing.cast(builtins.bool, jsii.sinvoke(cls, "isConstruct", [x]))
 
